@@ -84,7 +84,7 @@ class SyncSolver:
         if re.search("/recaptcha/(api2|enterprise)/userverify", response.url) is None:
             return
 
-        token_match = re.search(r'"uvresp","(.*?)"', response.text())
+        token_match = re.search('"uvresp","(.*?)"', response.text())
 
         if token_match is not None:
             self.token = token_match.group(1)
@@ -106,30 +106,35 @@ class SyncSolver:
         Raises
         ------
         RecaptchaRateLimitError
-            If the reCAPTCHA rate limit has been reached.
+            If the reCAPTCHA rate limit has been exceeded.
         """
         audio_challenge_button = recaptcha_frame.get_by_role(
             "button", name="Get an audio challenge"
         )
 
         if audio_challenge_button.is_visible():
-            audio_challenge_button.click()
+            audio_challenge_button.click(force=True)
+
+        play_button = recaptcha_frame.get_by_role("button", name="Press PLAY to listen")
+        rate_limit = recaptcha_frame.get_by_text("Try again later")
 
         while True:
-            if recaptcha_frame.get_by_text("Press PLAY to listen").is_visible():
+            if play_button.is_visible():
                 break
 
-            if recaptcha_frame.get_by_text("Try again later").is_visible():
+            if rate_limit.is_visible():
                 raise RecaptchaRateLimitError
 
             self._page.wait_for_timeout(100)
 
-        return recaptcha_frame.get_by_role(
+        audio_url = recaptcha_frame.get_by_role(
             "link", name="Alternatively, download audio as MP3"
-        ).get_attribute("href")
+        )
+
+        return audio_url.get_attribute("href")
 
     @staticmethod
-    def _convert_audio_to_text(audio_url: str) -> str:
+    def _convert_audio_to_text(audio_url: str) -> Optional[str]:
         """
         Convert the reCAPTCHA audio to text.
 
@@ -140,7 +145,7 @@ class SyncSolver:
 
         Returns
         -------
-        str
+        Optional[str]
             The reCAPTCHA audio text.
         """
         response = httpx.get(audio_url)
@@ -156,7 +161,7 @@ class SyncSolver:
             audio_data = recognizer.record(source)
 
         text = recognizer.recognize_google(audio_data, show_all=True)
-        return text["alternative"][0]["transcript"]
+        return text["alternative"][0]["transcript"] if text else None
 
     def _submit_audio_text(
         self, recaptcha_frame: Frame, recaptcha_checkbox: Locator, text: str
@@ -176,21 +181,22 @@ class SyncSolver:
         Raises
         ------
         RecaptchaRateLimitError
-            If the reCAPTCHA rate limit has been reached.
+            If the reCAPTCHA rate limit has been exceeded.
         """
         recaptcha_frame.get_by_role("textbox", name="Enter what you hear").fill(text)
         recaptcha_frame.get_by_role("button", name="Verify").click()
 
+        solve_failure = recaptcha_frame.get_by_text(
+            "Multiple correct solutions required - please solve more."
+        )
+
+        rate_limit = recaptcha_frame.get_by_text("Try again later")
+
         while not recaptcha_frame.is_detached():
-            if (
-                recaptcha_checkbox.is_checked()
-                or recaptcha_frame.get_by_text(
-                    "Multiple correct solutions required - please solve more."
-                ).is_visible()
-            ):
+            if recaptcha_checkbox.is_checked() or solve_failure.is_visible():
                 break
 
-            if recaptcha_frame.get_by_text("Try again later").is_visible():
+            if rate_limit.is_visible():
                 raise RecaptchaRateLimitError
 
             self._page.wait_for_timeout(100)
@@ -235,10 +241,12 @@ class SyncSolver:
 
         recaptcha_checkbox.click(force=True)
 
+        audio_challenge_button = recaptcha_frame.get_by_role(
+            "button", name="Get an audio challenge"
+        )
+
         while True:
-            if recaptcha_frame.get_by_role(
-                "button", name="Get an audio challenge"
-            ).is_enabled():
+            if audio_challenge_button.is_enabled():
                 break
 
             if recaptcha_checkbox.is_checked():
@@ -249,10 +257,20 @@ class SyncSolver:
 
             self._page.wait_for_timeout(100)
 
+        new_challenge_button = recaptcha_frame.get_by_role(
+            "button", name="Get a new challenge"
+        )
+
         while retries > 0:
             self._random_delay()
             url = self._get_audio_url(recaptcha_frame)
             text = self._convert_audio_to_text(url)
+
+            if text is None:
+                new_challenge_button.click()
+                retries -= 1
+                continue
+
             self._random_delay()
             self._submit_audio_text(recaptcha_frame, recaptcha_checkbox, text)
 
@@ -262,7 +280,7 @@ class SyncSolver:
 
                 return self.token
 
-            recaptcha_frame.get_by_role("button", name="Get a new challenge").click()
+            new_challenge_button.click()
             retries -= 1
 
         raise RecaptchaSolveError
